(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     44514,        991]
NotebookOptionsPosition[     43671,        969]
NotebookOutlinePosition[     44146,        987]
CellTagsIndexPosition[     44103,        984]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Mathematica code to solve numerically the Reaction - Diffusion \
PDEs",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0],
  Background->RGBColor[1., 0.8509803921568627, 0.8509803921568627]],
 StyleBox["\n",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Leonardo Dagdug,  Ivan Pompa-Garc\[IAcute]a,  Jason Pe\[NTilde]a",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["\n",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["From the book:\n ",
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Diffusion Under Confinement: A Journey Through Counterintuition",
  FontSize->18,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]]
}], "Subtitle",
 CellChangeTimes->{{3.897401317577585*^9, 3.8974013660192966`*^9}, {
   3.8974868042908697`*^9, 3.897486811354224*^9}, {3.897516572581173*^9, 
   3.897516575588283*^9}, {3.8975166187500067`*^9, 3.897516707916236*^9}, 
   3.897516818075986*^9, {3.900068372549721*^9, 3.900068377800004*^9}},
 TextAlignment->Center,ExpressionUUID->"4d3722ba-5c8b-4944-bbff-55d5fd88e01d"],

Cell[TextData[StyleBox["One-dimensional Gierer-Meinhardt model",
 FontSize->18,
 FontWeight->"Bold",
 FontSlant->"Italic",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.897401460848901*^9, 3.897401476999867*^9}, {
  3.8974025225957117`*^9, 
  3.897402523315486*^9}},ExpressionUUID->"e6e14cb0-f7a2-4e34-8a70-\
5bcee249265a"],

Cell[TextData[{
 StyleBox["Numerical solution of the coupled partial differential equations \
(PDEs) in  (13.55) and (13.56)  and its graphical representation.",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 "\nThe following code requires the values of the system length ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "7c7292b9-93ab-4a83-a2b3-cdb8ccf1ddd9"],
 ",  reaction rate ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "51ee2740-d6bc-4ba3-a25f-49361341c253"],
 ", diffusion coefficient ratio ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]],ExpressionUUID->
  "ca326fcd-e0b5-489e-9f7c-8dc73bc28a2f"],
 ", and computation time ",
 Cell[BoxData[
  FormBox[
   StyleBox["tc",
    FontSlant->"Italic"], TraditionalForm]],ExpressionUUID->
  "2702158e-1c4a-4691-9cab-bdc490b7a421"],
 ",  in that specific order. Its output provides the numerical solution of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "(", 
    RowBox[{"x", ",", "t"}], ")"}], TraditionalForm]],ExpressionUUID->
  "5fe0e84f-9ed6-498e-b591-896fc9f5d7fc"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"v", "(", 
    RowBox[{"x", ",", "t"}], ")"}], TraditionalForm]],ExpressionUUID->
  "54f7a8f8-2edc-44c3-b873-d5ef04876e60"],
 ", the concentration plot as a function of ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "30c7a76f-3233-4a1b-8411-7793e8280b2c"],
 ", and a density plot of concentration u(x). For example, if we wish to see \
the results for a system with",
 StyleBox["  ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"L", "=", "30"}], TraditionalForm]],
  FontSlant->"Italic",ExpressionUUID->
  "1e33cfe0-fdb9-4a79-b4e5-e3e050bcd1fb"],
 StyleBox[", ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox["b", TraditionalForm]],
  FontSlant->"Italic",ExpressionUUID->
  "a8f5a35f-9a3d-45b0-a69e-e7cef0e7fa53"],
 StyleBox["=0.35, ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"d", "=", "30"}], TraditionalForm]],
  FontSlant->"Italic",ExpressionUUID->
  "4bf6f08b-0529-4ee1-af31-350aea53ab67"],
 StyleBox[", and ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"tc", "=", "400"}], TraditionalForm]],ExpressionUUID->
  "e3cfa505-cdef-4f87-a4cd-5eff3789d48d"],
 StyleBox[", ",
  FontSlant->"Italic"],
 "we should write  ",
 StyleBox["PDEsSolution1D[30, 0.35, 30, 400]. ",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.89740248359444*^9, 3.89740250588867*^9}, {
   3.8974025858285437`*^9, 3.897402596992051*^9}, {3.8974041425321817`*^9, 
   3.8974041522107058`*^9}, 3.897404394767271*^9, 3.8974046231098013`*^9, {
   3.897404730461918*^9, 3.897404787926239*^9}, {3.8974236606324167`*^9, 
   3.8974236717921677`*^9}, {3.897423703927206*^9, 3.897423708470001*^9}, {
   3.897434417512166*^9, 3.897434448468951*^9}, {3.8974484749391537`*^9, 
   3.89744847979473*^9}, {3.897448531634713*^9, 3.897448557293221*^9}, {
   3.897448587842502*^9, 3.8974486931612167`*^9}, {3.8974775447193203`*^9, 
   3.897477550470541*^9}, {3.897477689157845*^9, 3.897477693981455*^9}, {
   3.897477737001295*^9, 3.897477737435938*^9}, {3.897486838394203*^9, 
   3.897486863329527*^9}, {3.897515213791604*^9, 3.897515213906869*^9}, {
   3.897516326120512*^9, 3.8975163317603197`*^9}, {3.897567170515415*^9, 
   3.897567176609974*^9}, {3.897659998504661*^9, 3.8976600086222277`*^9}, {
   3.897661409222574*^9, 3.897661410282139*^9}, {3.89766195028518*^9, 
   3.897661951571576*^9}, 
   3.897691930631987*^9},ExpressionUUID->"05b093a2-aaaa-4d2b-9fca-\
5663325f6326"],

Cell[TextData[{
 StyleBox["~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~IMPORTANT~~~~~~~~~\
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~",
  FontSize->14,
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["The entire code is confined within a single cell. It is imperative \
to exercise caution while executing the function, as it will yield the \
numerical solutions of the Partial Differential Equations (PDEs) and \
simultaneously generate both the concentration plots and the density plot",
  FontSize->12,
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~WARNING~~~~~~~~~~\
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["\n",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Be advised that the execution of the following command may \
necessitate a significant amount of time to complete, contingent upon the \
computational capabilities of your hardware. ",
  FontSize->12,
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.897489983012581*^9, 3.897490041712096*^9}, {
   3.8974907984773417`*^9, 3.897490845040402*^9}, 3.8974948183020678`*^9, 
   3.897662252962862*^9},
 TextAlignment->Center,ExpressionUUID->"401bbdcd-554d-43c4-93f5-572b214f2f94"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Definition", " ", "of", " ", "the", " ", "function", " ", 
     StyleBox[
      RowBox[{"PDEsSolution1D", "[", 
       RowBox[{"L", ",", " ", "b", ",", " ", "d", ",", " ", "tc"}], "]"}],
      FontSlant->"Italic"], " ", "for", " ", "the", " ", "one"}], "-", 
    RowBox[{"dimensional", " ", "Gierer"}], "-", 
    RowBox[{"Meinhardt", " ", "reaction"}], "-", 
    RowBox[{"diffusion", " ", "model"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"PDEsSolution1D", "[", 
     RowBox[{"L_", " ", 
      RowBox[{"(*", 
       RowBox[{"length", " ", "of", " ", "the", " ", "system"}], "*)"}], ",", 
      "b_", "  ", 
      RowBox[{"(*", 
       RowBox[{"reaction", " ", "rate"}], "*)"}], ",", " ", "d_", " ", 
      RowBox[{"(*", 
       RowBox[{"difussivity", " ", "ratio"}], "*)"}], ",", "tc_"}], " ", 
     RowBox[{"(*", 
      RowBox[{"computation", " ", "time"}], "*)"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "Specification", " ", "of", " ", "the", " ", "variables", " ", "used", 
      " ", "within", " ", "the", " ", "Module"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Dv", "=", "d"}], ",", " ", "PDEs", ",", " ", 
        "initialconditions", ",", " ", "x0", ",", " ", "BCs", ",", " ", "Eqs",
         ",", "Plotuv1D", ",", " ", "Densityplotuv"}], "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
         RowBox[{"**", "**", "**"}], "*", 
         RowBox[{
         "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
           "**", "**", "**", "**", "**", "NUMERICAL", "**", "SOLUTION", "**", 
          "OF", "**", "THE", "**", "REACTION"}]}], "-", 
        RowBox[{
        "DIFFUSION", "**", "SYSTEM", "**", "**", "**", "**", "**", "**", "**",
          "**", "**", "**", "**", "**", "**", "**", "**", "**"}]}], 
       "******)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"First", ",", " ", 
        RowBox[{
        "we", " ", "define", " ", "the", " ", "system", " ", "of", " ", 
         "partial", " ", "differential", " ", "equations", " ", 
         RowBox[{"(", "PDEs", ")"}], " ", "according", " ", "to", " ", 
         RowBox[{"Eqs", ".", " ", 
          RowBox[{"(", "13.55", ")"}]}], " ", "and", " ", 
         RowBox[{"(", "13.56", ")"}]}], ",", " ", "namely", ","}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"PDEs", "=", 
        RowBox[{"{", 
         RowBox[{"(*", 
          RowBox[{"Eq", ".", " ", 
           RowBox[{"(", "13.55", ")"}]}], "*)"}], 
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"u", "[", 
              RowBox[{"t", ",", "x"}], "]"}], ",", "t"}], "]"}], "==", 
           RowBox[{
            RowBox[{"Du", " ", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"u", "[", 
                RowBox[{"t", ",", "x"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", "2"}], "}"}]}], "]"}]}], "+", " ", 
            FractionBox[
             SuperscriptBox[
              RowBox[{"u", "[", 
               RowBox[{"t", ",", "x"}], "]"}], "2"], 
             RowBox[{"v", "[", 
              RowBox[{"t", ",", "x"}], "]"}]], "-", 
            RowBox[{"b", " ", 
             RowBox[{"u", "[", 
              RowBox[{"t", ",", "x"}], "]"}]}]}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"Eq", ".", 
            RowBox[{"(", "13.56", ")"}]}], "*)"}], 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"v", "[", 
              RowBox[{"t", ",", "x"}], "]"}], ",", "t"}], "]"}], "==", " ", 
           RowBox[{
            RowBox[{"Dv", " ", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"v", "[", 
                RowBox[{"t", ",", "x"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", "2"}], "}"}]}], "]"}]}], "+", 
            SuperscriptBox[
             RowBox[{"u", "[", 
              RowBox[{"t", ",", "x"}], "]"}], "2"], "-", 
            RowBox[{"v", "[", 
             RowBox[{"t", ",", "x"}], "]"}]}]}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "The", " ", "concentration", " ", "gradients", " ", "of", " ", "the",
           " ", "substances", " ", "are", " ", "represented", " ", "as", " ", 
          
          RowBox[{"u", "[", 
           RowBox[{"t", ",", "x"}], "]"}], " ", 
          RowBox[{"(", "activator", ")"}], " ", "and", " ", 
          RowBox[{"v", "[", 
           RowBox[{"t", ",", "x"}], "]"}], " ", 
          RowBox[{
           RowBox[{"(", "inhibitor", ")"}], ".", "The"}], " ", "variables", 
          " ", "inside", " ", "the", " ", "square", " ", "brackets", " ", 
          "indicate", " ", "the", " ", "dependence", " ", "of", " ", "both", 
          " ", "functions", " ", "u", " ", "and", " ", "v", " ", "on", " ", 
          "time", " ", "and", " ", "space"}], ",", " ", 
         RowBox[{"while", " ", "the", " ", "command", " ", 
          RowBox[{
           StyleBox["D",
            FontSlant->"Italic"], 
           StyleBox["[",
            FontSlant->"Italic"], 
           RowBox[{
            RowBox[{
             StyleBox["f",
              FontSlant->"Italic"], 
             StyleBox["[",
              FontSlant->"Italic"], 
             RowBox[{
              StyleBox["x1",
               FontSlant->"Italic"], ",", 
              StyleBox["x2",
               FontSlant->"Italic"], 
              StyleBox[",",
               FontSlant->"Italic"], 
              StyleBox["x3",
               FontSlant->"Italic"], ",", "...", ",", "xn"}], 
             StyleBox["]",
              FontSlant->"Italic"]}], 
            StyleBox[",",
             FontSlant->"Italic"], 
            RowBox[{
             StyleBox["{",
              FontSlant->"Italic"], 
             RowBox[{
              StyleBox["xn",
               FontSlant->"Italic"], ",", "m"}], 
             StyleBox["}",
              FontSlant->"Italic"]}]}], 
           StyleBox["]",
            FontSlant->"Italic"]}], 
          StyleBox[" ",
           FontSlant->"Italic"], "gives", " ", "the", " ", Cell[TextData[
          StyleBox["m-",
           FontSlant->"Italic"]],ExpressionUUID->
           "c4e04871-f6a4-4b16-b2c3-1d7f1ef413af"], "order", " ", "partial", 
          " ", "derivative", " ", "of", " ", "function", " ", 
          StyleBox["f",
           FontSlant->"Italic"], 
          StyleBox[" ",
           FontSlant->"Italic"], "with", " ", "respect", " ", "to", " ", 
          RowBox[{Cell[TextData[Cell[BoxData[
            FormBox["xn", TraditionalForm]],
            FontSlant->"Italic",ExpressionUUID->
            "57cfbd26-722a-4d9e-b701-c841da535411"]],ExpressionUUID->
            "353bdf4d-1d2d-4a7d-8a6f-c147314180a8"], ".", " ", "Thus"}]}], 
         ",", " ", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"u", "[", 
             RowBox[{"t", ",", "x"}], "]"}], ",", "t"}], "]"}], " ", 
          "denotes", " ", "partial", " ", "derivative", " ", "of", " ", 
          RowBox[{"u", "[", 
           RowBox[{"t", ",", "x"}], "]"}], " ", "with", " ", "respect", " ", 
          "to", " ", 
          RowBox[{"time", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "For", " ", "the", " ", "sake", " ", "of", " ", "simplicity"}], ",", 
         " ", 
         RowBox[{
          RowBox[{"we", " ", "set", " ", "Du"}], "=", "1"}]}], "*)"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Du", "=", "1"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Now", ",", " ", 
         RowBox[{
         "we", " ", "set", " ", "the", " ", "initial", " ", "and", " ", 
          "boundary", " ", 
          RowBox[{"conditions", ".", " ", "On"}], " ", "the", " ", "one", " ",
           "hand"}], ",", 
         RowBox[{
         "a", " ", "random", " ", "value", " ", "x0", " ", "is", " ", 
          "selected", " ", "within", " ", "the", " ", 
          RowBox[{"interval", " ", "[", 
           RowBox[{"0", ",", "L"}], "]"}], " ", "to", " ", "represent", " ", 
          "the", " ", "initial", " ", "position", " ", "of", " ", "species", 
          " ", "u"}], ",", " ", 
         RowBox[{"i", ".", "e", "."}], ","}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"x0", "=", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", "L"}], "}"}], "]"}]}], ";", "                   ",
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
          RowBox[{
          "This", " ", "selection", " ", "is", " ", "based", " ", "on", " ", 
           "a", " ", "Gaussian"}], "-", 
          RowBox[{
          "like", " ", "distribution", " ", "centered", " ", "at", " ", 
           RowBox[{"x0", ".", " ", "On"}], " ", "the", " ", "other", " ", 
           "hand"}]}], ",", " ", 
         RowBox[{
         "we", " ", "choose", " ", "a", " ", "constant", " ", "value", " ", 
          "for", " ", 
          RowBox[{
           RowBox[{"v", "[", 
            RowBox[{"0", ",", " ", "x"}], "]"}], ".", " ", "Therefore"}]}], 
         ",", " ", 
         RowBox[{
         "the", " ", "initial", " ", "conditions", " ", "are", " ", "given", 
          " ", "by"}]}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"initialconditions", "=", 
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"u", "[", 
            RowBox[{"0", ",", "x"}], "]"}], "==", 
           RowBox[{
            RowBox[{"1", "/", "b"}], " ", "+", " ", 
            RowBox[{"Exp", "[", 
             RowBox[{"-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x", "-", "x0"}], ")"}], "2"]}], "]"}]}]}], ",", " ", 
          
          RowBox[{
           RowBox[{"v", "[", 
            RowBox[{"0", ",", "x"}], "]"}], "==", 
           RowBox[{"1", "/", 
            SuperscriptBox["b", "2"]}]}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "When", " ", "opting", " ", "for", " ", "periodic", " ", "boundary", 
          " ", "conditions"}], ",", " ", 
         RowBox[{"we", " ", "are", " ", "lead", " ", "to", " ", "write"}]}], 
        "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"BCs", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"u", "[", 
            RowBox[{"t", ",", "0"}], "]"}], "==", 
           RowBox[{"u", "[", 
            RowBox[{"t", ",", "L"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"v", "[", 
            RowBox[{"t", ",", "0"}], "]"}], "==", 
           RowBox[{"v", "[", 
            RowBox[{"t", ",", "L"}], "]"}]}]}], "}"}]}], " ", ";", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Moving", " ", "forward"}], ",", " ", 
         RowBox[{
         "we", " ", "associate", " ", "the", " ", "initial", " ", "and", " ", 
          "boundary", " ", "conditions", " ", "to", " ", "the", " ", "PDEs", 
          " ", "by", " ", "using", " ", "the", " ", 
          StyleBox["Join",
           FontSlant->"Italic"], 
          StyleBox[" ",
           FontSlant->"Italic"], "command", " ", "in", " ", "Mathematica"}], 
         ",", " ", 
         RowBox[{"this", " ", "is"}]}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"Eqs", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"PDEs", ",", "initialconditions", ",", "BCs"}], "]"}]}], ";",
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Finally", ",", " ", 
         RowBox[{
         "we", " ", "solve", " ", "numerically", " ", "the", " ", "system", 
          " ", "of", " ", "PDEs", " ", "over", " ", "the", " ", "given", " ", 
          
          RowBox[{"range", " ", "[", 
           RowBox[{"0", ",", " ", "tc"}], "]"}], " ", "for", " ", "t", " ", 
          RowBox[{"and", " ", "[", 
           RowBox[{"0", ",", " ", "L"}], "]"}], " ", "for", " ", 
          RowBox[{"x", ".", " ", "The"}], " ", "solution", " ", "is", " ", 
          "obtained", " ", "by", " ", "means", " ", "of", " ", "the", " ", 
          StyleBox["NDSolve",
           FontSlant->"Italic"], " ", "command", " ", "and", " ", "we", " ", 
          "name", " ", "the", " ", "solution", " ", 
          StyleBox["solution1D",
           FontSlant->"Italic"]}]}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"solution1D", "=", 
        RowBox[{"NDSolve", "[", 
         RowBox[{"Eqs", " ", 
          RowBox[{"(*", 
           RowBox[{
           "System", " ", "of", " ", "PDEs", " ", "to", " ", "solve"}], 
           "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"u", ",", "v"}], "}"}], " ", 
          RowBox[{"(*", 
           RowBox[{
           "variables", " ", "we", " ", "wish", " ", "to", " ", "solve"}], 
           "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "tc"}], "}"}], " ", 
          RowBox[{"(*", 
           RowBox[{"computation", " ", "time"}], "*)"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "L"}], "}"}]}], " ", 
         RowBox[{"(*", 
          RowBox[{"spatial", " ", "domain"}], "*)"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", "**", "**"}], "*", 
         RowBox[{
         "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
           "**", "**", "**", "**", "**", "VISUALIZATION", "**", "OF", "**", 
          "RESULTS", "**", "AND", "**", "DENSITY", "**", "PLOT", "**", "**", "**",
           "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
           "**"}]}], "******)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "The", " ", "rest", " ", "of", " ", "the", " ", "code", " ", "is", 
          " ", "intended", " ", "to", " ", "show", " ", "the", " ", 
          "position", " ", "dependent", " ", "plots", " ", "of", " ", 
          "concentrations", " ", "u", 
          RowBox[{"(", "x", ")"}], " ", "and", " ", "v", 
          RowBox[{"(", "x", ")"}], " ", "in", " ", "blue", " ", "and", " ", 
          "orange"}], ",", "respectively", ",", " ", 
         RowBox[{"at", " ", "different", " ", 
          RowBox[{"times", ".", " ", "We"}], " ", "incorporated", " ", 
          "controls", " ", "to", " ", "enable", " ", "interactive", " ", 
          "time", " ", 
          RowBox[{"manipulation", ".", " ", "Additionally"}]}], ",", " ", 
         RowBox[{
          RowBox[{
          "a", " ", "density", " ", "plot", " ", "is", " ", "displayed", " ", 
           "in", " ", "the", " ", "plane", " ", "x"}], "-", 
          RowBox[{"t", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "Plot", " ", "of", " ", "the", " ", "concentration", " ", 
          "gradients"}], " ", "~~", 
         RowBox[{"the", " ", "variable", " ", 
          StyleBox["time",
           FontSlant->"Italic"], " ", "is", " ", "a", " ", "dummy", " ", 
          "variable"}], "~~"}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"Plotuv1D", "=", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"We", " ", "use", " ", "the", " ", 
          StyleBox["Animate",
           FontSlant->"Italic"], 
          StyleBox[" ",
           FontSlant->"Italic"], "command", " ", "to", " ", "animate", " ", 
          "the", " ", "plot"}], "*)"}], "\[IndentingNewLine]", " ", 
        RowBox[{"Animate", "[", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
          "Evaluating", " ", "functions", " ", "u", " ", "and", " ", "v", " ",
            "at", " ", "the", " ", "numerical", " ", "solution", " ", 
           StyleBox["solution1D",
            FontSlant->"Italic"], 
           StyleBox[" ",
            FontSlant->"Italic"], "and", " ", "plotting", " ", "its", " ", 
           "result"}], "*)"}], 
         RowBox[{
          RowBox[{"Plot", "[", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"u", "[", 
                 RowBox[{"time", ",", "x"}], "]"}], ",", " ", 
                RowBox[{"v", "[", 
                 RowBox[{"time", ",", "x"}], "]"}]}], "}"}], "/.", 
              "solution1D"}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"(*", 
             RowBox[{
             "Selecting", " ", "spatial", " ", "domain", " ", "of", " ", 
              "the", " ", "plot"}], "*)"}], "\[IndentingNewLine]", " ", 
            RowBox[{"{", 
             RowBox[{"x", ",", "0", ",", "L"}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"(*", 
             RowBox[{
             "Detailed", " ", "specification", " ", "of", " ", "legends"}], 
             "*)"}], "\[IndentingNewLine]", 
            RowBox[{"PlotLegends", "->", 
             RowBox[{"{", 
              RowBox[{"\"\<u(x)\>\"", ",", " ", "\"\<v(x)\>\""}], "}"}]}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{"(*", 
             RowBox[{"Frame", " ", "Labels"}], "*)"}], "\[IndentingNewLine]", 
            
            RowBox[{"Frame", "->", "True"}], ",", " ", 
            RowBox[{"FrameLabel", "->", 
             RowBox[{"{", 
              RowBox[{
              "\"\<Position x\>\"", ",", " ", 
               "\"\<Concentration gradient\>\""}], "}"}]}], " ", ",", 
            "\[IndentingNewLine]", 
            RowBox[{"(*", 
             RowBox[{"Fixing", " ", "plot", " ", "range"}], "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"PlotRange", "->", 
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "12"}], "}"}]}]}], " ", "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
           "Time", " ", "domain", " ", "of", " ", "the", " ", "animation", 
            " ", "increasing", " ", "in", " ", "steps", " ", "of", " ", Cell[
            TextData[{
             Cell[BoxData[
              FormBox["tc", TraditionalForm]],
              FontSlant->"Italic",ExpressionUUID->
              "d07654b9-6a11-43ce-94b4-59bdd6e3bbe6"],
             StyleBox["/100",
              FontSlant->"Italic"]
            }],ExpressionUUID->"518ba70e-087e-4466-9d80-b71caac29635"]}], 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"time", ",", " ", "0", ",", "tc", " ", ",", 
            RowBox[{"tc", "/", "100"}]}], "}"}], ",", 
          "                                    ", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
           "Selecting", " ", "manual", " ", "reproduction", " ", "of", " ", 
            "the", " ", "animation"}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"AnimationRunning", "->", "False"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "Density", " ", "plot", " ", "of", " ", "the", " ", 
          "concentration"}], " ", "~~", 
         RowBox[{"the", " ", "variable", " ", 
          StyleBox["time",
           FontSlant->"Italic"], " ", "is", " ", "a", " ", "dummy", " ", 
          "variable"}], "~~"}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"Densityplotuv", "=", "  ", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{
         "Making", " ", "a", " ", "density", " ", "plot", " ", "of", " ", 
          "function", " ", "u", " ", "evaluated", " ", "at", " ", "the", " ", 
          "numerical", " ", "solution", " ", 
          StyleBox["solution1D",
           FontSlant->"Italic"]}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"DensityPlot", "[", 
         RowBox[{
          RowBox[{"Evaluate", "[", 
           RowBox[{
            RowBox[{"u", "[", 
             RowBox[{"time", ",", " ", "x"}], "]"}], " ", "/.", " ", 
            "solution1D"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
           "Selecting", " ", "spatial", " ", "domain", " ", "of", " ", "the", 
            " ", "plot"}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"x", ",", " ", "0", ",", " ", "L"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
           "Time", " ", "domain", " ", "of", " ", "the", " ", "density", " ", 
            "plot"}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"time", ",", " ", "0", ",", " ", "tc"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"Plot", " ", "label"}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"PlotLabel", "->", 
           RowBox[{"Style", "[", "\"\<Concentration u(x)\>\"", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
           "Detailed", " ", "specification", " ", "of", " ", "frame", " ", 
            "labels"}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"Frame", "->", "True"}], ",", 
          RowBox[{"FrameLabel", "->", 
           RowBox[{"{", 
            RowBox[{"\"\<Position x\>\"", ",", " ", "\"\<Time t\>\""}], 
            "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
           "Definition", " ", "of", " ", "a", " ", "color", " ", "style"}], 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{"ColorFunction", " ", "->", " ", "\"\<SolarColors\>\""}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{
            "Using", " ", "100", " ", "initial", " ", "sample", " ", 
             "points"}], " ", "~~", 
            RowBox[{
            "Higher", " ", "values", " ", "give", " ", "smoother", " ", 
             "plots"}], "~~"}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"PlotPoints", " ", "->", " ", "100"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
           "Size", " ", "to", " ", "display", " ", "the", " ", "plot"}], 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "->", "300"}]}], "]"}]}], " ", ";", 
       "\[IndentingNewLine]", "\n", 
       RowBox[{"(*", 
        RowBox[{"Finally", ",", " ", 
         RowBox[{
         "we", " ", "show", " ", "all", " ", "previous", " ", "results", " ", 
          "in", " ", "the", " ", "form", " ", "of", " ", "a", " ", "list"}], 
         ",", " ", 
         RowBox[{
         "specifically", " ", "the", " ", "numerical", " ", "solution"}], ",",
          " ", 
         RowBox[{"the", " ", "concentration", " ", "plot"}], ",", " ", 
         RowBox[{"and", " ", "the", " ", "density", " ", 
          RowBox[{"plot", ":"}]}]}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "solution1D", ",", " ", "Plotuv1D", ",", " ", "Densityplotuv"}], 
        "}"}]}]}], "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Subsequently", ",", " ", 
     RowBox[{
      RowBox[{
      "we", " ", "undertake", " ", "the", " ", "solution", " ", "of", " ", 
       "the", " ", "system", " ", "with", " ", 
       StyleBox["L",
        FontSlant->"Italic"]}], 
      StyleBox["=",
       FontSlant->"Italic"], 
      StyleBox["80",
       FontSlant->"Italic"]}], 
     StyleBox[",",
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], 
     StyleBox[
      RowBox[{"b", "=", "0.35"}],
      FontSlant->"Italic"], 
     StyleBox[",",
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], 
     StyleBox[
      RowBox[{"d", "=", "30"}],
      FontSlant->"Italic"], 
     StyleBox[",",
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], 
     StyleBox[
      RowBox[{
       RowBox[{"and", " ", "tc"}], "=", "400"}],
      FontSlant->"Italic"], ",", " ", 
     RowBox[{
     "using", " ", "the", " ", "latter", " ", "function", " ", "as", " ", 
      StyleBox[
       RowBox[{"PDEsSolution1D", "[", 
        RowBox[{"80", ",", " ", "0.35", ",", " ", "30", ",", " ", "400"}], 
        "]"}],
       FontSlant->"Italic"]}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"PDEsSolution1D", "[", 
    RowBox[{"100", ",", " ", "0.35", ",", " ", "30", ",", "400"}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"As", " ", "we", " ", "can", " ", "see"}], ",", " ", 
     RowBox[{
      RowBox[{
      "the", " ", "concentration", " ", "gradient", " ", "of", " ", "both", 
       " ", "substances", " ", "starts", " ", "to", " ", "oscillate", " ", 
       "along", " ", "the", " ", "x"}], "-", 
      RowBox[{
      "axis", " ", "and", " ", "after", " ", "a", " ", "certain", " ", "time",
        " ", "both", " ", "functions", " ", "reach", " ", "a", " ", 
       "steady"}], "-", "state"}]}], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "The", " ", "reader", " ", "may", " ", "change", " ", "the", " ", 
      "values", " ", "of", " ", "any", " ", "of", " ", "the", " ", 
      "parameters", " ", "in", " ", "order", " ", "to", " ", "see", " ", 
      "the", " ", "role", " ", "of", " ", "the", " ", "reaction", " ", "rate",
       " ", 
      StyleBox["b",
       FontSlant->"Italic"]}], ",", " ", 
     RowBox[{"critical", " ", "length", " ", Cell[TextData[Cell[BoxData[
       FormBox["Lc", TraditionalForm]],
       FontSlant->"Italic",ExpressionUUID->
       "dd83e720-1ea7-430a-866e-46443bc5a272"]],ExpressionUUID->
       "23356ebc-4d3f-49e3-a926-69fc8eb1d066"]}], ",", " ", 
     RowBox[{
     "critical", " ", "diffusion", " ", "coefficient", " ", "ratio", " ", 
      Cell[TextData[Cell[BoxData[
       FormBox["dc", TraditionalForm]],
       FontSlant->"Italic",ExpressionUUID->
       "99c77e90-cb17-4c07-866f-dece1ed6e2c1"]],ExpressionUUID->
       "8fc9687f-de06-4339-90fc-652ba01fd748"]}], ",", " ", 
     RowBox[{"and", " ", "time", " ", "computation", " ", 
      RowBox[{
       SubscriptBox["t", "c"], ".", " ", "For"}], " ", "instance"}], ",", " ", 
     RowBox[{"by", " ", "using", " ", 
      RowBox[{"Eq", ".", " ", 
       RowBox[{"(", "13.74", ")"}]}]}], ",", " ", 
     RowBox[{
     "we", " ", "see", " ", "that", " ", "the", " ", "critical", " ", 
      "lenght", " ", "is", " ", "about", " ", Cell[TextData[Cell[BoxData[
       FormBox[
        RowBox[{
         StyleBox["Lc",
          FontSlant->"Italic"], 
         StyleBox["=",
          FontSlant->"Italic"], " ", "12.0"}], TraditionalForm]],
       ExpressionUUID->"88ce937b-d89c-47cc-a64f-08a8370b6146"]],
       ExpressionUUID->"4ffcc410-1492-4c0f-ae4c-9f7f42ec89af"]}], ",", " ", 
     RowBox[{
     "meaning", " ", "that", " ", "below", " ", "that", " ", "value"}], ",", 
     " ", 
     RowBox[{
     "the", " ", "concentration", " ", "remain", " ", "approximately", " ", 
      "constant", " ", "and", " ", "no", " ", "patterns", " ", "emerge", " ", 
      "in", " ", "the", " ", "density", " ", 
      RowBox[{"plot", ".", " ", "Therefore"}]}], ",", " ", 
     RowBox[{"as", " ", "the", " ", "domain", " ", "size", " ", "increases"}],
      ",", 
     RowBox[{
     "the", " ", "substance", " ", "concentration", " ", "exhibits", " ", 
      "steeper", " ", "transitions"}]}], "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.8974019745525427`*^9, 3.897401999163774*^9}, {
   3.897402031724728*^9, 3.897402065471385*^9}, {3.8974021046144876`*^9, 
   3.897402209105351*^9}, {3.897402258827991*^9, 3.897402297612981*^9}, {
   3.897402330703034*^9, 3.897402398832117*^9}, {3.8974024449284687`*^9, 
   3.897402461635015*^9}, {3.897402745290112*^9, 3.8974027566364098`*^9}, {
   3.897403527910972*^9, 3.8974035962573547`*^9}, {3.897403673539521*^9, 
   3.897403716612887*^9}, {3.8974039627230167`*^9, 3.897403965108828*^9}, {
   3.897404166290909*^9, 3.8974043169116096`*^9}, {3.897404365726528*^9, 
   3.897404371251059*^9}, {3.897404504033778*^9, 3.897404504784181*^9}, {
   3.897404547538005*^9, 3.8974046089764233`*^9}, {3.8974047972735443`*^9, 
   3.8974049104638433`*^9}, {3.897404947425931*^9, 3.897404986206525*^9}, {
   3.897405035334827*^9, 3.897405083647583*^9}, {3.897405151906373*^9, 
   3.897405206079299*^9}, {3.897405238175084*^9, 3.897405261807877*^9}, {
   3.897406355963764*^9, 3.897406374131976*^9}, {3.897406609813343*^9, 
   3.897406630678934*^9}, 3.897406669878385*^9, {3.897406978402445*^9, 
   3.8974069965947742`*^9}, {3.897407168977007*^9, 3.897407170752412*^9}, {
   3.8974072518988123`*^9, 3.897407281673617*^9}, {3.897407317283936*^9, 
   3.8974073255685167`*^9}, {3.897407398387164*^9, 3.897407474675209*^9}, 
   3.897407514591207*^9, {3.897407550287541*^9, 3.897407663974492*^9}, {
   3.8974078486706133`*^9, 3.897407851076624*^9}, {3.8974078934370327`*^9, 
   3.897407901468093*^9}, {3.897407966253583*^9, 3.8974081235834417`*^9}, {
   3.8974081803174963`*^9, 3.897408188566271*^9}, {3.8974083058053913`*^9, 
   3.8974083507241917`*^9}, 3.8974220934474*^9, {3.897422157194357*^9, 
   3.897422210099791*^9}, {3.897422274562806*^9, 3.89742236722512*^9}, {
   3.8974225724315233`*^9, 3.897422605881014*^9}, {3.897422715827454*^9, 
   3.897422760680852*^9}, 3.897423340103207*^9, {3.897423566014241*^9, 
   3.897423652344404*^9}, {3.897423732099493*^9, 3.897423754554122*^9}, {
   3.8974239479955673`*^9, 3.8974241445459146`*^9}, {3.897425283904381*^9, 
   3.89742528751149*^9}, {3.8974320287999287`*^9, 3.8974320584277363`*^9}, {
   3.8974340173735437`*^9, 3.897434020555478*^9}, 3.897434455362537*^9, {
   3.897434534581633*^9, 3.897434564411487*^9}, {3.897434601771192*^9, 
   3.897434775711005*^9}, {3.897440383832835*^9, 3.897440502318143*^9}, {
   3.8974405822212667`*^9, 3.897440586667564*^9}, {3.897440637752686*^9, 
   3.897440672285762*^9}, {3.897440724324625*^9, 3.897440767875721*^9}, {
   3.8974427183254023`*^9, 3.897442739878273*^9}, {3.897442794149884*^9, 
   3.897442816283435*^9}, {3.897442897170163*^9, 3.897442911618062*^9}, {
   3.897443005397897*^9, 3.897443067724531*^9}, {3.897443123269252*^9, 
   3.897443148203677*^9}, {3.897443299833704*^9, 3.897443300662723*^9}, {
   3.897443356978982*^9, 3.897443412802812*^9}, {3.897443487281554*^9, 
   3.897443509198422*^9}, {3.897443893309136*^9, 3.897443898505424*^9}, {
   3.8974439991814623`*^9, 3.89744402801756*^9}, {3.897444189820655*^9, 
   3.897444192098526*^9}, {3.897444548997015*^9, 3.8974445534563417`*^9}, {
   3.8974447360214853`*^9, 3.897444748369493*^9}, {3.897444926472271*^9, 
   3.897444931320355*^9}, {3.897444969823784*^9, 3.8974450410125628`*^9}, {
   3.897445154534337*^9, 3.897445197740368*^9}, {3.8974452914597893`*^9, 
   3.897445310419631*^9}, {3.8974453702625017`*^9, 3.897445373485561*^9}, 
   3.897445411538732*^9, 3.8974455113146772`*^9, {3.897445557554051*^9, 
   3.8974457430251017`*^9}, {3.897447080998691*^9, 3.897447174162013*^9}, {
   3.897447328295968*^9, 3.8974473552296*^9}, {3.8974474347020483`*^9, 
   3.897447491943997*^9}, {3.897447526169711*^9, 3.897447615988817*^9}, {
   3.897447776074391*^9, 3.897447915197606*^9}, {3.897448025804309*^9, 
   3.897448046028311*^9}, {3.897448094352467*^9, 3.897448119360045*^9}, {
   3.8974481596488543`*^9, 3.897448237771102*^9}, {3.8974482812582283`*^9, 
   3.897448301857623*^9}, {3.897448342441579*^9, 3.89744837566391*^9}, {
   3.897448422041747*^9, 3.8974484638289547`*^9}, {3.897448578208815*^9, 
   3.89744858148225*^9}, {3.897448784436315*^9, 3.897448798438302*^9}, {
   3.89744885558477*^9, 3.8974488620541887`*^9}, 3.897448951363056*^9, {
   3.897449005057207*^9, 3.897449030164316*^9}, {3.897449061500017*^9, 
   3.897449168245838*^9}, {3.897449205511097*^9, 3.897449322594262*^9}, {
   3.8974494019377117`*^9, 3.897449467390088*^9}, 3.897449499165452*^9, {
   3.897449624303883*^9, 3.897449763004834*^9}, {3.897449802843961*^9, 
   3.8974499888335047`*^9}, {3.897450029727068*^9, 3.897450256375214*^9}, {
   3.8974502896935587`*^9, 3.8974503047157717`*^9}, {3.8974503467029943`*^9, 
   3.8974503691077957`*^9}, {3.897450416783616*^9, 3.897450417398966*^9}, {
   3.897450451535664*^9, 3.89745047108844*^9}, {3.897450504936795*^9, 
   3.897450511176044*^9}, {3.897450563587614*^9, 3.8974507108707237`*^9}, {
   3.897450743846291*^9, 3.897450839635714*^9}, {3.897450891633787*^9, 
   3.897451172546536*^9}, {3.897476044194628*^9, 3.897476090608487*^9}, {
   3.89747617679561*^9, 3.89747626383993*^9}, {3.897476294760318*^9, 
   3.897476295013665*^9}, {3.8974765390030203`*^9, 3.897476560440048*^9}, {
   3.89747679842488*^9, 3.8974768016104527`*^9}, {3.89747689568425*^9, 
   3.897476903930661*^9}, {3.897476992764988*^9, 3.897477006101668*^9}, 
   3.897477130975418*^9, {3.897477235980184*^9, 3.897477290257649*^9}, 
   3.897477342545993*^9, {3.897477382565752*^9, 3.897477387699328*^9}, {
   3.897477421274805*^9, 3.897477445395048*^9}, {3.897477811469887*^9, 
   3.897477833845903*^9}, 3.897478531343639*^9, {3.897478742444014*^9, 
   3.897478743375585*^9}, {3.897478882987651*^9, 3.897478883611911*^9}, {
   3.897479754120229*^9, 3.897479765833775*^9}, {3.8974801338889847`*^9, 
   3.8974801341099777`*^9}, {3.897480273859263*^9, 3.897480291503783*^9}, {
   3.897481510758101*^9, 3.897481510909059*^9}, {3.897481740310122*^9, 
   3.89748175593005*^9}, {3.897481809259453*^9, 3.897482029412736*^9}, {
   3.897484253346677*^9, 3.897484275654272*^9}, {3.897484920070961*^9, 
   3.897484939137384*^9}, {3.8974868803633757`*^9, 3.897486899094903*^9}, 
   3.897486953781046*^9, {3.897487010578885*^9, 3.897487024661265*^9}, {
   3.897487135721129*^9, 3.897487249625161*^9}, {3.8974872914796667`*^9, 
   3.897487366849532*^9}, {3.897487435743898*^9, 3.8974874647040033`*^9}, {
   3.89748755624057*^9, 3.8974875602042437`*^9}, {3.897487721094968*^9, 
   3.89748776344806*^9}, {3.897488031670683*^9, 3.897488034511207*^9}, 
   3.897488115968381*^9, {3.897488495313838*^9, 3.897488516783904*^9}, {
   3.897507146524246*^9, 3.897507146794121*^9}, {3.8975072415087137`*^9, 
   3.897507294336685*^9}, {3.89750779176223*^9, 3.8975078959367533`*^9}, {
   3.897514470893545*^9, 3.897514492906548*^9}, {3.897526989920319*^9, 
   3.897527002069727*^9}, {3.897563450760056*^9, 3.897563450947694*^9}, {
   3.8975671621275806`*^9, 3.897567162301455*^9}, {3.8975793122955236`*^9, 
   3.897579312362822*^9}, {3.897582786277693*^9, 3.8975827961807203`*^9}, {
   3.897584903016971*^9, 3.89758493463174*^9}, {3.8976600133563137`*^9, 
   3.897660160518095*^9}, {3.897660193935852*^9, 3.897660226042194*^9}, {
   3.897660336271908*^9, 3.897660381867051*^9}, {3.8976604119482603`*^9, 
   3.897660526764941*^9}, {3.8976605656649523`*^9, 3.8976605794730864`*^9}, 
   3.897660635681856*^9, {3.8976608450713463`*^9, 3.897660858016151*^9}, {
   3.897660965064728*^9, 3.897660982228965*^9}, {3.897661792285163*^9, 
   3.897661827041045*^9}, {3.897661864166397*^9, 3.897661936018385*^9}, {
   3.897662025155841*^9, 3.8976620640541267`*^9}, {3.8976620959936447`*^9, 
   3.897662096892745*^9}, {3.897666442713211*^9, 3.897666463318695*^9}, {
   3.897684016210031*^9, 3.897684103758655*^9}, {3.8976841910731916`*^9, 
   3.897684218353217*^9}, {3.8976842945916443`*^9, 3.8976843673308067`*^9}, {
   3.8976845013720818`*^9, 3.8976845037032423`*^9}, {3.897684620287887*^9, 
   3.897685199889263*^9}, {3.8976853181237926`*^9, 3.8976853198223047`*^9}, {
   3.897685365775756*^9, 3.897685374247019*^9}, 3.8976855343784447`*^9, 
   3.8976855671468153`*^9, {3.897685681615654*^9, 3.897685738487187*^9}, {
   3.897686827919982*^9, 3.897686853801229*^9}, {3.897686904810121*^9, 
   3.897686906551601*^9}, 3.8976870525402527`*^9},
 TextJustification->1.,
 CellLabel->"In[5]:=",ExpressionUUID->"3a68f10c-4bd9-4171-b5a7-06c581692bc2"]
}, Open  ]]
},
WindowSize->{1020., 782.25},
WindowMargins->{{-1016.6698674860764`, 
  1431.9685039370079`}, {-197.1259842519686, Automatic}},
Magnification:>1.2 Inherited,
FrontEndVersion->"13.2 for Linux x86 (64-bit) (January 31, 2023)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"0bf219fa-169e-4246-a336-c4cd8917ba40"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 1103, 27, 144, "Subtitle",ExpressionUUID->"4d3722ba-5c8b-4944-bbff-55d5fd88e01d"],
Cell[1686, 51, 340, 8, 45, "Text",ExpressionUUID->"e6e14cb0-f7a2-4e34-8a70-5bcee249265a"],
Cell[2029, 61, 3543, 89, 180, "Text",ExpressionUUID->"05b093a2-aaaa-4d2b-9fca-5663325f6326"],
Cell[5575, 152, 1358, 30, 160, "Text",ExpressionUUID->"401bbdcd-554d-43c4-93f5-572b214f2f94"],
Cell[6936, 184, 36719, 782, 3123, "Input",ExpressionUUID->"3a68f10c-4bd9-4171-b5a7-06c581692bc2"]
}, Open  ]]
}
]
*)

