(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     45387,       1043]
NotebookOptionsPosition[     44575,       1022]
NotebookOutlinePosition[     45019,       1039]
CellTagsIndexPosition[     44976,       1036]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Mathematica code to solve numerically the Reaction - Diffusion \
PDEs",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0],
  Background->RGBColor[1, 0.85, 0.85]],
 StyleBox["\n",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Leonardo Dagdug,  Ivan Pompa-Garc\[IAcute]a,  Jason Pe\[NTilde]a",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["\n",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["From the book:\n ",
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Diffusion Under Confinement: A Journey Through Counterintuition",
  FontSize->18,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]]
}], "Subtitle",
 CellChangeTimes->{{3.897401317577585*^9, 3.8974013660192966`*^9}, {
   3.8974868042908697`*^9, 3.897486811354224*^9}, {3.897516572581173*^9, 
   3.897516575588283*^9}, {3.8975166187500067`*^9, 3.897516707916236*^9}, 
   3.897516818075986*^9, {3.900068396735251*^9, 3.9000684041721354`*^9}},
 TextAlignment->Center,ExpressionUUID->"b0255901-d493-4cff-84f7-c351a606fc1a"],

Cell[TextData[StyleBox["Two-dimensional Gierer-Meinhardt model",
 FontSize->18,
 FontWeight->"Bold",
 FontSlant->"Italic",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.897401460848901*^9, 3.897401476999867*^9}, {
  3.8974025225957117`*^9, 3.897402523315486*^9}, {3.897447400171657*^9, 
  3.897447401612692*^9}},ExpressionUUID->"a9e538f1-f95d-45af-9975-\
e1a03160a1e5"],

Cell[TextData[{
 StyleBox["Numerical solution of the coupled partial differential equations \
(PDEs) in  (13.73) and (13.74)  and its graphical representation.\n",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 "The following code requires the values of the system length ",
 Cell[BoxData[
  FormBox[
   StyleBox["Lx",
    FontSlant->"Italic"], TraditionalForm]],ExpressionUUID->
  "9faaa214-f96d-4ee3-9e5f-e5948de66f62"],
 " and ",
 Cell[BoxData[
  FormBox["Ly", TraditionalForm]],
  FontSlant->"Italic",ExpressionUUID->
  "8bc6ddf1-2220-44cd-ae15-f05cfca8cf86"],
 ",  reaction rate ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", diffusion coefficient ratio ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]],ExpressionUUID->
  "fbf81b04-0a97-491c-a835-3ed43bdb6580"],
 ", and computation time ",
 Cell[BoxData[
  FormBox["tc", TraditionalForm]],
  FontSlant->"Italic",ExpressionUUID->
  "85d91c8d-d52b-4941-8001-e077c4fdbc60"],
 ",  in that specific order. Its output provides the numerical solution of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "(", 
    RowBox[{"x", ",", "y", ",", "t"}], ")"}], TraditionalForm]],
  ExpressionUUID->"a9c8b719-c216-4476-99ff-17501a72cd58"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"v", "(", 
    RowBox[{"x", ",", "y", ",", "t"}], ")"}], TraditionalForm]],
  ExpressionUUID->"2bd682fe-f008-4cb4-ad99-58e11506bb00"],
 ", the concentration plot as a function of ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "40a975f6-78f9-4ccd-a0d7-b10e89a180ed"],
 " and ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]],ExpressionUUID->
  "90b8e78f-d096-48ee-a737-4ad73419c9f9"],
 ", and a density plot of concentrations. For example, if we wish to see the \
results for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Lx", "=", "80"}], TraditionalForm]],
  FontSlant->"Italic",ExpressionUUID->
  "7cf2d1e8-56b1-4ae6-b939-f8c250bfb115"],
 StyleBox[", ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Ly", "=", "10"}], ","}], TraditionalForm]],ExpressionUUID->
  "0c9c1a95-26ca-4437-9c68-9bee12c7950a"],
 StyleBox[" b=0.45, ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"d", "=", "30"}], TraditionalForm]],
  FontSlant->"Italic",ExpressionUUID->
  "57e30a75-3328-4591-9f73-9265f76b63e7"],
 StyleBox[", and ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["tc",
     FontSlant->"Italic"], "=", "1000"}], TraditionalForm]],
  FontSlant->"Italic",ExpressionUUID->
  "f749fc7d-ba0c-4df6-873a-5c78c4b333d3"],
 StyleBox[",",
  FontSlant->"Italic"],
 " we should write  ",
 StyleBox["PDEsSolution2D[80, 10, 0.45, 30, 1000]",
  FontSlant->"Italic"],
 ". "
}], "Text",
 CellChangeTimes->{{3.897477614448276*^9, 3.89747762114918*^9}, {
   3.897477651950552*^9, 3.897477655708753*^9}, {3.897477709524701*^9, 
   3.897477718525097*^9}, {3.897477757162203*^9, 3.897477787289085*^9}, {
   3.897478936042643*^9, 3.8974789816669483`*^9}, {3.897586716525784*^9, 
   3.897586719213067*^9}, 3.897660031584116*^9, {3.8976606798477507`*^9, 
   3.897660689209711*^9}, {3.897661751275762*^9, 
   3.897661772251511*^9}},ExpressionUUID->"4742f0dd-3fe5-4ecb-8b9a-\
20d8521eceb0"],

Cell[TextData[{
 StyleBox["~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~IMPORTANT~~~~~~~~~\
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~",
  FontSize->14,
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["The entire code is confined within a single cell. It is imperative \
to exercise caution while executing the function, as it will yield the \
numerical solutions of the Partial Differential Equations (PDEs) and \
simultaneously generate  the density plot animation.",
  FontSize->12,
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~WARNING~~~~~~~~~~\
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["\n",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Be advised that the execution of the following command may \
necessitate a significant amount of time to complete, contingent upon the \
computational capabilities of your hardware.",
  FontSize->12,
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.897489983012581*^9, 3.897490041712096*^9}, {
   3.8974907984773417`*^9, 3.897490845040402*^9}, {3.897490908442793*^9, 
   3.8974909124196157`*^9}, 3.897494900810972*^9, 3.89766224289819*^9},
 TextAlignment->Center,ExpressionUUID->"f9b8c0fe-e360-49c2-8840-dbcd62f0fb3e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Definition", " ", "of", " ", "the", " ", "function", " ", 
     RowBox[{
      StyleBox["PDEsSolution2D",
       FontSlant->"Italic"], 
      StyleBox["[",
       FontSlant->"Italic"], 
      RowBox[{
       StyleBox["Lx",
        FontSlant->"Italic"], 
       StyleBox[",",
        FontSlant->"Italic"], 
       StyleBox["Ly",
        FontSlant->"Italic"], ",", 
       StyleBox["b",
        FontSlant->"Italic"], 
       StyleBox[",",
        FontSlant->"Italic"], 
       StyleBox[" ",
        FontSlant->"Italic"], 
       StyleBox["d",
        FontSlant->"Italic"], 
       StyleBox[",",
        FontSlant->"Italic"], 
       StyleBox[" ",
        FontSlant->"Italic"], 
       StyleBox["tc",
        FontSlant->"Italic"]}], 
      StyleBox["]",
       FontSlant->"Italic"]}], " ", "for", " ", "the", " ", "two"}], "-", 
    RowBox[{"dimensional", " ", "Gierer"}], "-", 
    RowBox[{"Meinhardt", " ", "reaction"}], "-", 
    RowBox[{"diffusion", " ", "model"}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"PDEsSolution2D", "[", 
     RowBox[{"Lx_", " ", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"length", " ", "along", " ", "the", " ", "x"}], "-", "axis"}],
        "*)"}], ",", "Ly_", " ", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"length", " ", "along", " ", "the", " ", "y"}], "-", "axis"}],
        "*)"}], ",", "\[IndentingNewLine]", "b_", "  ", 
      RowBox[{"(*", 
       RowBox[{"reaction", " ", "rate"}], "*)"}], ",", " ", "d_", " ", 
      RowBox[{"(*", 
       RowBox[{"difussivity", " ", "ratio"}], "*)"}], ",", "tc_"}], " ", 
     RowBox[{"(*", 
      RowBox[{"computation", " ", "time"}], "*)"}], "]"}], ":=", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "Specification", " ", "of", " ", "the", " ", "variables", " ", "used", 
      " ", "within", " ", "the", " ", "Module"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Dv", "=", "d"}], ",", " ", "PDEs", ",", " ", 
        "initialconditions", ",", " ", "x0", ",", " ", "BCs", ",", " ", "Eqs",
         ",", " ", "Densityplotuv"}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
         RowBox[{"**", "**", "**"}], "*", 
         RowBox[{
         "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
           "**", "**", "**", "**", "**", "NUMERICAL", "**", "SOLUTION", "**", 
          "OF", "**", "THE", "**", "REACTION"}]}], "-", 
        RowBox[{
        "DIFFUSION", "**", "SYSTEM", "**", "**", "**", "**", "**", "**", "**",
          "**", "**", "**", "**", "**", "**", "**", "**", "**"}]}], 
       "******)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"First", ",", " ", 
        RowBox[{
        "we", " ", "define", " ", "the", " ", "system", " ", "of", " ", 
         "partial", " ", "differential", " ", "equations", " ", 
         RowBox[{"(", "PDEs", ")"}], " ", "according", " ", "to", " ", 
         RowBox[{"Eqs", ".", " ", 
          RowBox[{"(", "13.73", ")"}]}], " ", "and", " ", 
         RowBox[{"(", "13.74", ")"}]}], ",", " ", "namely", ","}], "*)"}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"PDEs", "=", 
        RowBox[{"{", 
         RowBox[{"(*", 
          RowBox[{"Eq", ".", 
           RowBox[{"(", "13.73", ")"}]}], "*)"}], 
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"u", "[", 
              RowBox[{"t", ",", "x", ",", "y"}], "]"}], ",", " ", "t"}], 
            "]"}], "==", 
           RowBox[{
            RowBox[{"Du", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{
                 RowBox[{"u", "[", 
                  RowBox[{"t", ",", "x", ",", "y"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"x", ",", "2"}], "}"}]}], "]"}], "+", 
               RowBox[{"D", "[", 
                RowBox[{
                 RowBox[{"u", "[", 
                  RowBox[{"t", ",", "x", ",", "y"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}], ")"}]}], "+", 
            FractionBox[
             SuperscriptBox[
              RowBox[{"u", "[", 
               RowBox[{"t", ",", "x", ",", " ", "y"}], "]"}], "2"], 
             RowBox[{"v", "[", 
              RowBox[{"t", ",", "x", ",", " ", "y"}], "]"}]], "-", 
            RowBox[{"b", " ", 
             RowBox[{"u", "[", 
              RowBox[{"t", ",", "x", ",", " ", "y"}], "]"}]}]}]}], ",", " ", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"Eq", ".", 
            RowBox[{"(", "13.74", ")"}]}], "*)"}], 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"v", "[", 
              RowBox[{"t", ",", "x", ",", "y"}], "]"}], ",", " ", "t"}], 
            "]"}], "==", 
           RowBox[{
            RowBox[{"Dv", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{
                 RowBox[{"v", "[", 
                  RowBox[{"t", ",", "x", ",", "y"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"x", ",", "2"}], "}"}]}], "]"}], "+", 
               RowBox[{"D", "[", 
                RowBox[{
                 RowBox[{"v", "[", 
                  RowBox[{"t", ",", "x", ",", "y"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}], ")"}]}], "+", 
            SuperscriptBox[
             RowBox[{"u", "[", 
              RowBox[{"t", ",", "x", ",", " ", "y"}], "]"}], "2"], "-", 
            RowBox[{"v", "[", 
             RowBox[{"t", ",", "x", ",", " ", "y"}], "]"}]}]}]}], "}"}]}], 
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "The", " ", "concentration", " ", "gradients", " ", "of", " ", "the",
           " ", "substances", " ", "are", " ", "represented", " ", "as", " ", 
          
          RowBox[{"u", "[", 
           RowBox[{"t", ",", "x", ",", "y"}], "]"}], " ", 
          RowBox[{"(", "activator", ")"}], " ", "and", " ", 
          RowBox[{"v", "[", 
           RowBox[{"t", ",", "x", ",", "y"}], "]"}], " ", 
          RowBox[{
           RowBox[{"(", "inhibitor", ")"}], ".", "The"}], " ", "variables", 
          " ", "inside", " ", "the", " ", "square", " ", "brackets", " ", 
          "indicate", " ", "the", " ", "dependence", " ", "of", " ", "both", 
          " ", "functions", " ", "u", " ", "and", " ", "v", " ", "on", " ", 
          "time", " ", "and", " ", "space"}], ",", " ", 
         RowBox[{"while", " ", "the", " ", "command", " ", 
          RowBox[{
           StyleBox["D",
            FontSlant->"Italic"], 
           StyleBox["[",
            FontSlant->"Italic"], 
           RowBox[{
            RowBox[{
             StyleBox["f",
              FontSlant->"Italic"], 
             StyleBox["[",
              FontSlant->"Italic"], 
             RowBox[{
              StyleBox["x1",
               FontSlant->"Italic"], ",", 
              StyleBox["x2",
               FontSlant->"Italic"], 
              StyleBox[",",
               FontSlant->"Italic"], "...", ",", "xn"}], 
             StyleBox["]",
              FontSlant->"Italic"]}], 
            StyleBox[",",
             FontSlant->"Italic"], 
            RowBox[{
             StyleBox["{",
              FontSlant->"Italic"], 
             RowBox[{
              StyleBox["xn",
               FontSlant->"Italic"], ",", "m"}], 
             StyleBox["}",
              FontSlant->"Italic"]}]}], 
           StyleBox["]",
            FontSlant->"Italic"]}], 
          StyleBox[" ",
           FontSlant->"Italic"], "gives", " ", "the", " ", Cell[TextData[
          StyleBox["m-",
           FontSlant->"Italic"]],ExpressionUUID->
           "18239055-9d8c-4ac9-8942-2725f1d93e03"], "order", " ", "partial", 
          " ", "derivative", " ", "of", " ", "function", " ", 
          StyleBox["f",
           FontSlant->"Italic"], 
          StyleBox[" ",
           FontSlant->"Italic"], "with", " ", "respect", " ", "to", " ", 
          RowBox[{Cell[TextData[Cell[BoxData[
            FormBox["xn", TraditionalForm]],
            FontSlant->"Italic",ExpressionUUID->
            "df0a6ca1-4626-415e-a567-64710ee1aeb8"]],ExpressionUUID->
            "ca9a45ea-9cce-4bfd-acaf-9ed34366c31d"], ".", " ", "Thus"}]}], 
         ",", " ", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"u", "[", 
             RowBox[{"t", ",", "x", ",", "y"}], "]"}], ",", "t"}], "]"}], " ",
           "denotes", " ", "partial", " ", "derivative", " ", "of", " ", 
          RowBox[{"u", "[", 
           RowBox[{"t", ",", "x", ",", "y"}], "]"}], " ", "with", " ", 
          "respect", " ", "to", " ", 
          RowBox[{"time", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "For", " ", "the", " ", "sake", " ", "of", " ", "simplicity"}], ",", 
         " ", 
         RowBox[{
          RowBox[{"we", " ", "set", " ", "Du"}], "=", "1"}]}], "*)"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Du", "=", "1"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Now", ",", " ", 
         RowBox[{
         "we", " ", "set", " ", "the", " ", "initial", " ", "and", " ", 
          "boundary", " ", 
          RowBox[{"conditions", ".", " ", "On"}], " ", "the", " ", "one", " ",
           "hand"}], ",", " ", 
         RowBox[{
          RowBox[{
          "a", " ", "random", " ", "values", " ", "x0", " ", "is", " ", 
           "selected", " ", "within", " ", "the", " ", 
           RowBox[{"interval", " ", "[", 
            RowBox[{"0", ",", " ", "Lx"}], "]"}], " ", "to", " ", "represent",
            " ", "the", " ", "initial", " ", "position", " ", "of", " ", 
           "species", " ", 
           RowBox[{"u", " ", ".", " ", "This"}], " ", "selection", " ", "is", 
           " ", "based", " ", "on", " ", "a", " ", "Gaussian"}], "-", 
          RowBox[{
          "like", " ", "distribution", " ", "centered", " ", "at", " ", 
           RowBox[{
            RowBox[{"(", Cell[TextData[{
              Cell[BoxData[
               FormBox["x0", TraditionalForm]],ExpressionUUID->
               "16245096-a424-4372-9f71-6eaa0234054e"],
              ", y"
             }],ExpressionUUID->"8ca7458b-d2e8-4dae-9354-2b16bcf53608"], 
             ")"}], "."}]}]}], ",", " ", 
         RowBox[{"i", ".", "e", "."}], ","}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"x0", "=", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "Lx"}], "}"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", " ", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"On", " ", "the", " ", "other", " ", "hand"}], ",", " ", 
         RowBox[{
         "we", " ", "choose", " ", "a", " ", "constant", " ", "value", " ", 
          "for", " ", 
          RowBox[{
           RowBox[{"v", "[", 
            RowBox[{"0", ",", "x", ",", "y"}], "]"}], ".", " ", 
           "Therefore"}]}], ",", " ", 
         RowBox[{
         "the", " ", "initial", " ", "conditions", " ", "are", " ", "given", 
          " ", "by"}]}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"initialconditions", "=", 
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"u", "[", 
            RowBox[{"0", ",", "x", ",", "y"}], "]"}], "==", 
           RowBox[{
            RowBox[{"1", "/", "b"}], " ", "+", " ", 
            RowBox[{"Exp", "[", 
             RowBox[{"-", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x", "-", "x0"}], ")"}], "2"]}], "]"}]}]}], ",", " ", 
          
          RowBox[{
           RowBox[{"v", "[", 
            RowBox[{"0", ",", "x", ",", "y"}], "]"}], "==", 
           RowBox[{"1", "/", 
            SuperscriptBox["b", "2"]}]}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "When", " ", "opting", " ", "for", " ", "periodic", " ", "boundary", 
          " ", "conditions"}], ",", " ", 
         RowBox[{"we", " ", "are", " ", "lead", " ", "to", " ", "write"}]}], 
        "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"BCs", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"u", "[", 
            RowBox[{"t", ",", "0", ",", "y"}], "]"}], "==", 
           RowBox[{"u", "[", 
            RowBox[{"t", ",", "Lx", ",", "y"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"v", "[", 
            RowBox[{"t", ",", "x", ",", "0"}], "]"}], "==", 
           RowBox[{"v", "[", 
            RowBox[{"t", ",", " ", "x", ",", " ", "Ly"}], "]"}]}]}], "}"}]}], 
       ";", " ", "\n", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Moving", " ", "forward"}], ",", " ", 
         RowBox[{
         "we", " ", "associate", " ", "the", " ", "PDEs", " ", "to", " ", 
          "the", " ", "initial", " ", "and", " ", "boundary", " ", 
          "conditions", " ", "using", " ", "the", " ", 
          StyleBox["Join",
           FontSlant->"Italic"], 
          StyleBox[" ",
           FontSlant->"Italic"], "command", " ", "in", " ", "Mathematica"}], 
         ",", " ", 
         RowBox[{"this", " ", "is"}]}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", " ", 
       RowBox[{"Eqs", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"PDEs", ",", "initialconditions", ",", "BCs"}], "]"}]}], ";",
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Finally", ",", " ", 
         RowBox[{
         "we", " ", "solve", " ", "numerically", " ", "the", " ", "system", 
          " ", "of", " ", "PDEs", " ", "in", " ", "the", " ", 
          RowBox[{"range", " ", "[", 
           RowBox[{"0", ",", " ", "tc"}], "]"}], " ", "for", " ", "t"}], ",", 
         " ", 
         RowBox[{
          RowBox[{"[", 
           RowBox[{"0", ",", " ", "Lx"}], "]"}], " ", "for", " ", "x"}], ",", 
         
         RowBox[{
          RowBox[{"and", " ", "[", 
           RowBox[{"0", ",", " ", "Ly"}], "]"}], " ", "for", " ", 
          RowBox[{"y", ".", " ", "The"}], " ", "solution", " ", "is", " ", 
          "obtained", " ", "by", " ", "meansthe", " ", "NDSolve", " ", 
          "comman", " ", "and", " ", "we", " ", "name", " ", "the", " ", 
          "solution", " ", 
          StyleBox["solution2D",
           FontSlant->"Italic"]}]}], "*)"}], "\n", "\[IndentingNewLine]", 
       RowBox[{"solution2D", "=", 
        RowBox[{"NDSolve", "[", 
         RowBox[{"Eqs", " ", 
          RowBox[{"(*", 
           RowBox[{
           "System", " ", "of", " ", "PDEs", " ", "to", " ", "solve"}], 
           "*)"}], ",", 
          RowBox[{"{", 
           RowBox[{"u", ",", "v"}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "tc"}], "}"}], " ", 
          RowBox[{"(*", 
           RowBox[{"computation", " ", "time"}], "*)"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"y", ",", "0", ",", "Ly"}], "}"}], 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{
            "spatial", " ", "domain", " ", "along", " ", "the", " ", "y"}], 
            "-", "axis"}], "*)"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "Lx"}], "}"}]}], " ", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
           "spatial", " ", "domain", " ", "along", " ", "the", " ", "x"}], 
           "-", "axis"}], "*)"}], "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", "**", "**"}], "*", 
         RowBox[{
         "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
           "**", "**", "**", "**", "**", "VISUALIZATION", "**", "OF", "**", 
          "RESULTS", "**", "AND", "**", "DENSITY", "**", "PLOT", "**", "**", "**",
           "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
           "**"}]}], "******)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "The", " ", "rest", " ", "of", " ", "the", " ", "code", " ", "is", 
         " ", "intended", " ", "to", " ", "show", " ", "the", " ", "density", 
         " ", "plots", " ", "of", " ", "concentrations", " ", "u", 
         RowBox[{"(", 
          RowBox[{"x", ",", " ", "y"}], ")"}], " ", "and", " ", "v", 
         RowBox[{"(", 
          RowBox[{"x", ",", " ", "y"}], ")"}], " ", "with", " ", 
         "incorporated", " ", "controls", " ", "to", " ", "enable", " ", 
         "interactive", " ", "time", " ", 
         RowBox[{"manipulation", "."}]}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "Density", " ", "plot", " ", "of", " ", "the", " ", 
          "concentration"}], " ", "~~", 
         RowBox[{"the", " ", "variable", " ", 
          StyleBox["time",
           FontSlant->"Italic"], " ", "is", " ", "a", " ", "dummy", " ", 
          "variable"}], "~~"}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"Densityplotuv", "=", "   ", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"We", " ", "use", " ", "the", " ", 
          StyleBox["ListAnimate",
           FontSlant->"Italic"], 
          StyleBox[" ",
           FontSlant->"Italic"], "command", " ", "to", " ", "animate", " ", 
          "results", " ", "of", " ", "the", " ", 
          StyleBox["Table",
           FontSlant->"Italic"], 
          StyleBox[" ",
           FontSlant->"Italic"], "below"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"ListAnimate", "[", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
          "Generating", " ", "a", " ", "list", " ", "of", " ", "the", " ", 
           StyleBox["DensityPlot",
            FontSlant->"Italic"], 
           StyleBox[" ",
            FontSlant->"Italic"], "when", " ", Cell[TextData[StyleBox["time",
            FontSlant->"Italic"]],ExpressionUUID->
            "09a31365-d5b8-4ef5-89de-e2aeb4c13ec6"], " ", 
           StyleBox["goes",
            FontSlant->"Plain"], 
           StyleBox[" ",
            FontSlant->"Plain"], 
           StyleBox["from",
            FontSlant->"Plain"], 
           StyleBox[" ",
            FontSlant->"Plain"], 
           StyleBox["0",
            FontSlant->"Plain"], 
           StyleBox[" ",
            FontSlant->"Plain"], 
           StyleBox["to",
            FontSlant->"Plain"], 
           StyleBox[" ",
            FontSlant->"Plain"], Cell[TextData[Cell[BoxData[
            FormBox["tc", TraditionalForm]],
            FontSlant->"Italic",ExpressionUUID->
            "fa32fd81-d101-439e-a1e6-82ba5761cc97"]],ExpressionUUID->
            "f1d656e3-22ff-44bd-9859-8b897f6da275"]}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Table", "[", " ", "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{
            "Making", " ", "a", " ", "density", " ", "plot", " ", "of", " ", 
             "function", " ", "v", " ", "evaluated", " ", "at", " ", "the", 
             " ", "numerical", " ", "solution", " ", 
             StyleBox["solution2D",
              FontSlant->"Italic"]}], "*)"}], "\[IndentingNewLine]", " ", 
           RowBox[{
            RowBox[{"DensityPlot", "[", 
             RowBox[{
              RowBox[{"Evaluate", "[", 
               RowBox[{
                RowBox[{"v", "[", 
                 RowBox[{"time", ",", " ", "x", ",", " ", "y"}], "]"}], " ", "/.",
                 " ", "solution2D"}], "]"}], ",", "\[IndentingNewLine]", 
              RowBox[{"(*", 
               RowBox[{
               "Selecting", " ", "spatial", " ", "domain", " ", "of", " ", 
                "the", " ", "plot"}], "*)"}], "\[IndentingNewLine]", " ", 
              RowBox[{"{", 
               RowBox[{"x", ",", " ", "0", ",", " ", "Lx"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"y", ",", " ", "0", ",", " ", "Ly"}], "}"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"(*", 
               RowBox[{
               "Definition", " ", "of", " ", "a", " ", "color", " ", 
                "style"}], "*)"}], "\n", "               ", 
              RowBox[{
              "ColorFunction", " ", "->", " ", "\"\<SolarColors\>\""}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"(*", 
               RowBox[{"Plot", " ", "label"}], "*)"}], "\[IndentingNewLine]", 
              
              RowBox[{"PlotLabel", "->", 
               RowBox[{
               "Style", "[", "\"\<Concentraci\[OAcute]n de u(x,t)\>\"", 
                "]"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{"(*", 
               RowBox[{"Frame", " ", "label"}], "*)"}], "\[IndentingNewLine]", 
              RowBox[{"FrameLabel", "->", 
               RowBox[{"{", 
                RowBox[{"\"\<Position x\>\"", ",", "\"\<Position y\>\""}], 
                "}"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{"(*", 
               RowBox[{
                RowBox[{
                "Using", " ", "100", " ", "initial", " ", "sample", " ", 
                 "points"}], " ", "~~", 
                RowBox[{
                "Higher", " ", "values", " ", "give", " ", "smoother", " ", 
                 "plots"}], "~~"}], "*)"}], "\[IndentingNewLine]", " ", 
              RowBox[{"PlotPoints", " ", "->", " ", "100"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"(*", 
               RowBox[{
               "Automatic", " ", "set", " ", "up", " ", "of", " ", "ratio", 
                " ", "of", " ", "height", " ", "to", " ", "width", " ", "of", 
                " ", "the", " ", "plot"}], "*)"}], "\[IndentingNewLine]", " ", 
              RowBox[{"AspectRatio", "->", "Automatic"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"(*", 
             RowBox[{
             "Time", " ", "domain", " ", "of", " ", "the", " ", "animation", 
              " ", "increasing", " ", "in", " ", "steps", " ", "of", " ", 
              Cell[TextData[{
               Cell[BoxData[
                FormBox["tc", TraditionalForm]],
                FontSlant->"Italic",ExpressionUUID->
                "d3d9542d-620f-4398-bea7-ede73a3d8b1d"],
               "/100"
              }],ExpressionUUID->"1792d122-65f5-43e2-b7b0-4fe83e7adfc9"]}], 
             "*)"}], "\[IndentingNewLine]", " ", 
            RowBox[{"{", 
             RowBox[{"time", ",", " ", "0", ",", " ", "tc", ",", " ", 
              RowBox[{"tc", "/", "100"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
           "Selecting", " ", "manual", " ", "reproduction", " ", "of", " ", 
            "the", " ", "animation"}], "*)"}], "\[IndentingNewLine]", " ", 
          RowBox[{"AnimationRunning", "->", "False"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Finally", ",", " ", 
         RowBox[{
         "we", " ", "show", " ", "previous", " ", "results", " ", "in", " ", 
          "the", " ", "form", " ", "of", " ", "a", " ", "list"}], ",", " ", 
         RowBox[{
         "specifically", " ", "the", " ", "numerical", " ", "solution", " ", 
          "and", " ", "the", " ", "density", " ", "plot"}]}], "*)"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"solution2D", ",", "  ", "Densityplotuv"}], "}"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Subsequently", ",", " ", 
     RowBox[{
      RowBox[{
      "we", " ", "undertake", " ", "the", " ", "solution", " ", "of", " ", 
       "the", " ", "system", " ", "with", " ", 
       StyleBox["Lx",
        FontSlant->"Italic"]}], 
      StyleBox["=",
       FontSlant->"Italic"], 
      StyleBox["80",
       FontSlant->"Italic"]}], 
     StyleBox[",",
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], 
     StyleBox[
      RowBox[{"Ly", "=", "10"}],
      FontSlant->"Italic"], 
     StyleBox[",",
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], 
     StyleBox[
      RowBox[{"b", "=", "0.45"}],
      FontSlant->"Italic"], 
     StyleBox[",",
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], 
     StyleBox[
      RowBox[{"d", "=", "30"}],
      FontSlant->"Italic"], 
     StyleBox[",",
      FontSlant->"Italic"], " ", 
     RowBox[{
      RowBox[{"and", " ", 
       StyleBox["tc",
        FontSlant->"Italic"]}], 
      StyleBox["=",
       FontSlant->"Italic"], 
      StyleBox["1000",
       FontSlant->"Italic"]}], ",", " ", 
     RowBox[{
     "using", " ", "the", " ", "latter", " ", "function", " ", "as", " ", 
      StyleBox[
       RowBox[{"PDEsSolution2D", "[", 
        RowBox[{
        "80", ",", " ", "10", ",", " ", "0.45", ",", " ", "30", ",", " ", 
         "1000"}], "]"}],
       FontSlant->"Italic"]}]}], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"PDEsSolution2D", "[", 
    RowBox[{"80", "  ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"length", " ", "along", " ", "the", " ", "x"}], "-", "axis"}], 
      "*)"}], ",", "80", "  ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"length", " ", "along", " ", "the", " ", "y"}], "-", "axis"}], 
      "*)"}], ",", " ", "0.45", " ", 
     RowBox[{"(*", 
      RowBox[{"reaction", " ", "rate"}], "*)"}], ",", " ", "30", " ", 
     RowBox[{"(*", 
      RowBox[{"difussivity", " ", "ratio"}], "*)"}], ",", 
     "\[IndentingNewLine]", "2000"}], " ", 
    RowBox[{"(*", 
     RowBox[{"computation", " ", "time"}], "*)"}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "The", " ", "reader", " ", "may", " ", "change", " ", "the", " ", 
      "values", " ", "of", " ", "any", " ", "of", " ", "the", " ", 
      "parameters", " ", "in", " ", "order", " ", "to", " ", "see", " ", 
      "the", " ", "role", " ", "of", " ", "the", " ", "reaction", " ", "rate",
       " ", 
      StyleBox["b",
       FontSlant->"Italic"]}], ",", " ", 
     RowBox[{"domain", " ", "size"}], ",", " ", 
     RowBox[{
     "critical", " ", "diffusion", " ", "coefficient", " ", "ratio", " ", 
      Cell[TextData[Cell[BoxData[
       FormBox["dc", TraditionalForm]],ExpressionUUID->
       "fc417bcb-c434-4aa7-8532-b313db3ec54f"]],
       FontSlant->"Italic",ExpressionUUID->
       "31f0ab37-77b1-4ded-a79c-c3400f8d164c"]}], ",", " ", 
     RowBox[{"and", " ", "time", " ", "computation", " ", 
      RowBox[{
       StyleBox["tc",
        FontSlant->"Italic"], ".", " ", "For"}], " ", "instance"}], ",", " ", 
     
     RowBox[{"when", " ", "using", " ", 
      StyleBox[
       RowBox[{"PDEsSolution2D", "[", 
        RowBox[{
        "80", ",", " ", "10", ",", " ", "0.35", ",", " ", "30", ",", " ", 
         "400"}], "]"}],
       FontSlant->"Italic"]}], 
     StyleBox[",",
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], 
     RowBox[{
      StyleBox[
       RowBox[{
        StyleBox["t",
         FontSlant->"Italic"], "he"}]], " ", "resultant", " ", "patterns", 
      " ", "show", " ", "stripes"}], ",", " ", 
     RowBox[{
     "whereas", " ", "upon", " ", "employing", " ", "a", " ", "different", 
      " ", "configuration"}], ",", " ", 
     RowBox[{
     "say", " ", "a", " ", "square", " ", "system", " ", "with", " ", 
      StyleBox[
       RowBox[{"PDEsSolution2D", "[", 
        RowBox[{
        "80", ",", " ", "80", ",", " ", "0.45", ",", " ", "30", ",", " ", 
         "1000"}], "]"}],
       FontSlant->"Italic"]}], 
     StyleBox[",",
      FontSlant->"Italic"], 
     StyleBox[" ",
      FontSlant->"Italic"], 
     RowBox[{
      RowBox[{"dots", " ", "are", " ", 
       RowBox[{"observed", ".", "  ", "As"}], " ", "in", " ", "the", " ", 
       "one"}], "-", 
      RowBox[{"dimensional", " ", "case"}]}], ",", " ", 
     RowBox[{
     "we", " ", "conclude", " ", "that", " ", "the", " ", "larger", " ", 
      "the", " ", "diffusion", " ", "reaction", " ", "domain"}], ",", " ", 
     RowBox[{
     "the", " ", "more", " ", "complex", " ", "the", " ", "spatial", " ", 
      RowBox[{"patterns", "."}]}]}], "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.8974019745525427`*^9, 3.897401999163774*^9}, {
   3.897402031724728*^9, 3.897402065471385*^9}, {3.8974021046144876`*^9, 
   3.897402209105351*^9}, {3.897402258827991*^9, 3.897402297612981*^9}, {
   3.897402330703034*^9, 3.897402398832117*^9}, {3.8974024449284687`*^9, 
   3.897402461635015*^9}, {3.897402745290112*^9, 3.8974027566364098`*^9}, {
   3.897403527910972*^9, 3.8974035962573547`*^9}, {3.897403673539521*^9, 
   3.897403716612887*^9}, {3.8974039627230167`*^9, 3.897403965108828*^9}, {
   3.897404166290909*^9, 3.8974043169116096`*^9}, {3.897404365726528*^9, 
   3.897404371251059*^9}, {3.897404504033778*^9, 3.897404504784181*^9}, {
   3.897404547538005*^9, 3.8974046089764233`*^9}, {3.8974047972735443`*^9, 
   3.8974049104638433`*^9}, {3.897404947425931*^9, 3.897404986206525*^9}, {
   3.897405035334827*^9, 3.897405083647583*^9}, {3.897405151906373*^9, 
   3.897405206079299*^9}, {3.897405238175084*^9, 3.897405261807877*^9}, {
   3.897406355963764*^9, 3.897406374131976*^9}, {3.897406609813343*^9, 
   3.897406630678934*^9}, 3.897406669878385*^9, {3.897406978402445*^9, 
   3.8974069965947742`*^9}, {3.897407168977007*^9, 3.897407170752412*^9}, {
   3.8974072518988123`*^9, 3.897407281673617*^9}, {3.897407317283936*^9, 
   3.8974073255685167`*^9}, {3.897407398387164*^9, 3.897407474675209*^9}, 
   3.897407514591207*^9, {3.897407550287541*^9, 3.897407663974492*^9}, {
   3.8974078486706133`*^9, 3.897407851076624*^9}, {3.8974078934370327`*^9, 
   3.897407901468093*^9}, {3.897407966253583*^9, 3.8974081235834417`*^9}, {
   3.8974081803174963`*^9, 3.897408188566271*^9}, {3.8974083058053913`*^9, 
   3.8974083507241917`*^9}, 3.8974220934474*^9, {3.897422157194357*^9, 
   3.897422210099791*^9}, {3.897422274562806*^9, 3.89742236722512*^9}, {
   3.8974225724315233`*^9, 3.897422605881014*^9}, {3.897422715827454*^9, 
   3.897422760680852*^9}, 3.897423340103207*^9, {3.897423566014241*^9, 
   3.897423652344404*^9}, {3.897423732099493*^9, 3.897423754554122*^9}, {
   3.8974239479955673`*^9, 3.8974241445459146`*^9}, {3.897425283904381*^9, 
   3.89742528751149*^9}, {3.8974320287999287`*^9, 3.8974320584277363`*^9}, {
   3.8974340173735437`*^9, 3.897434020555478*^9}, 3.897434455362537*^9, {
   3.897434534581633*^9, 3.897434564411487*^9}, {3.897434601771192*^9, 
   3.897434775711005*^9}, {3.897440383832835*^9, 3.897440502318143*^9}, {
   3.8974405822212667`*^9, 3.897440586667564*^9}, {3.897440637752686*^9, 
   3.897440672285762*^9}, {3.897440724324625*^9, 3.897440767875721*^9}, {
   3.8974427183254023`*^9, 3.897442739878273*^9}, {3.897442794149884*^9, 
   3.897442816283435*^9}, {3.897442897170163*^9, 3.897442911618062*^9}, {
   3.897443005397897*^9, 3.897443067724531*^9}, {3.897443123269252*^9, 
   3.897443148203677*^9}, {3.897443299833704*^9, 3.897443300662723*^9}, {
   3.897443356978982*^9, 3.897443412802812*^9}, {3.897443487281554*^9, 
   3.897443509198422*^9}, {3.897443893309136*^9, 3.897443898505424*^9}, {
   3.8974439991814623`*^9, 3.89744402801756*^9}, {3.897444189820655*^9, 
   3.897444192098526*^9}, {3.897444548997015*^9, 3.8974445534563417`*^9}, {
   3.8974447360214853`*^9, 3.897444748369493*^9}, {3.897444926472271*^9, 
   3.897444931320355*^9}, {3.897444969823784*^9, 3.8974450410125628`*^9}, {
   3.897445154534337*^9, 3.897445197740368*^9}, {3.8974452914597893`*^9, 
   3.897445310419631*^9}, {3.8974453702625017`*^9, 3.897445373485561*^9}, 
   3.897445411538732*^9, 3.8974455113146772`*^9, {3.897445557554051*^9, 
   3.8974457430251017`*^9}, {3.897447080998691*^9, 3.897447174162013*^9}, {
   3.897447328295968*^9, 3.8974473552296*^9}, {3.8974474347020483`*^9, 
   3.897447491943997*^9}, {3.897447526169711*^9, 3.897447615988817*^9}, {
   3.897447776074391*^9, 3.897447915197606*^9}, {3.897448025804309*^9, 
   3.897448046028311*^9}, {3.897448094352467*^9, 3.897448119360045*^9}, {
   3.8974481596488543`*^9, 3.897448237771102*^9}, {3.8974482812582283`*^9, 
   3.897448301857623*^9}, {3.897448342441579*^9, 3.89744837566391*^9}, {
   3.897448422041747*^9, 3.8974484638289547`*^9}, {3.897448578208815*^9, 
   3.89744858148225*^9}, {3.897448784436315*^9, 3.897448798438302*^9}, {
   3.89744885558477*^9, 3.8974488620541887`*^9}, 3.897448951363056*^9, {
   3.897449005057207*^9, 3.897449030164316*^9}, {3.897449061500017*^9, 
   3.897449168245838*^9}, {3.897449205511097*^9, 3.897449322594262*^9}, {
   3.8974494019377117`*^9, 3.897449467390088*^9}, 3.897449499165452*^9, {
   3.897449624303883*^9, 3.897449763004834*^9}, {3.897449802843961*^9, 
   3.8974499888335047`*^9}, {3.897450029727068*^9, 3.897450256375214*^9}, {
   3.8974502896935587`*^9, 3.8974503047157717`*^9}, {3.8974503467029943`*^9, 
   3.8974503691077957`*^9}, {3.897450416783616*^9, 3.897450417398966*^9}, {
   3.897450451535664*^9, 3.89745047108844*^9}, {3.897450504936795*^9, 
   3.897450511176044*^9}, {3.897450563587614*^9, 3.8974507108707237`*^9}, {
   3.897450743846291*^9, 3.897450839635714*^9}, {3.897450891633787*^9, 
   3.897451172546536*^9}, {3.897476044194628*^9, 3.897476090608487*^9}, {
   3.89747617679561*^9, 3.89747626383993*^9}, {3.897476294760318*^9, 
   3.897476295013665*^9}, {3.8974765390030203`*^9, 3.897476560440048*^9}, {
   3.89747679842488*^9, 3.8974768016104527`*^9}, {3.89747689568425*^9, 
   3.897476903930661*^9}, {3.897476992764988*^9, 3.897477006101668*^9}, 
   3.897477130975418*^9, {3.897477235980184*^9, 3.897477290257649*^9}, 
   3.897477342545993*^9, {3.897477382565752*^9, 3.897477387699328*^9}, {
   3.897477421274805*^9, 3.897477445395048*^9}, {3.897477811469887*^9, 
   3.897477858219874*^9}, {3.897477902889052*^9, 3.897478021843442*^9}, {
   3.8974782240933237`*^9, 3.897478290416519*^9}, {3.8974783310578747`*^9, 
   3.897478521091166*^9}, {3.897478563158368*^9, 3.897478608780242*^9}, {
   3.8974786610397263`*^9, 3.89747872448141*^9}, {3.897478758209835*^9, 
   3.897478778686676*^9}, {3.897478821584867*^9, 3.897478854039566*^9}, {
   3.897478902402141*^9, 3.897478912346929*^9}, {3.8974789918013687`*^9, 
   3.897479027192059*^9}, {3.897479081554744*^9, 3.897479221364106*^9}, {
   3.8974792547618017`*^9, 3.897479570523169*^9}, {3.897479608300201*^9, 
   3.897479739313931*^9}, {3.897479801347321*^9, 3.897479849650639*^9}, {
   3.8974799121871643`*^9, 3.897480027845924*^9}, {3.897480064373263*^9, 
   3.897480069689755*^9}, {3.8974801091108093`*^9, 3.897480123870319*^9}, {
   3.897480318371908*^9, 3.897480404443659*^9}, {3.897480650131282*^9, 
   3.897480686509295*^9}, {3.897480726120118*^9, 3.897480726246304*^9}, {
   3.897480759467936*^9, 3.897480759825501*^9}, {3.89748102205618*^9, 
   3.897481022283413*^9}, {3.8974811464314337`*^9, 3.89748116078514*^9}, {
   3.8974812780607224`*^9, 3.897481278192603*^9}, {3.897481361534357*^9, 
   3.897481363693824*^9}, {3.897481496062572*^9, 3.897481496181566*^9}, {
   3.8974825185229397`*^9, 3.897482518686783*^9}, {3.897482556494318*^9, 
   3.897482561317005*^9}, {3.897482751710881*^9, 3.897482758617197*^9}, {
   3.897483387054579*^9, 3.897483388890604*^9}, {3.897484154709214*^9, 
   3.8974842175072403`*^9}, {3.897484299812715*^9, 3.897484349000656*^9}, {
   3.897484435244618*^9, 3.897484468655244*^9}, {3.897484530310141*^9, 
   3.897484530674034*^9}, 3.897484619586937*^9, {3.897484892920484*^9, 
   3.897484894360046*^9}, {3.8974850283715897`*^9, 3.897485031168051*^9}, {
   3.8974853133542557`*^9, 3.897485313564269*^9}, {3.897485568250848*^9, 
   3.897485606713279*^9}, 3.897485803151812*^9, {3.897485892237032*^9, 
   3.897485892674405*^9}, 3.897485956649972*^9, {3.8974859949878197`*^9, 
   3.897486000998104*^9}, {3.897486065495471*^9, 3.897486137244883*^9}, {
   3.89748624269458*^9, 3.897486290429984*^9}, {3.897487990217702*^9, 
   3.897488076778639*^9}, {3.897488127513956*^9, 3.8974881334607*^9}, {
   3.897488175169976*^9, 3.8974881927172117`*^9}, {3.897488237476857*^9, 
   3.897488271970702*^9}, {3.897507917892109*^9, 3.897507918105627*^9}, {
   3.897586000504386*^9, 3.8975860006600533`*^9}, {3.897586396022595*^9, 
   3.897586396140362*^9}, {3.897586693431375*^9, 3.897586703712379*^9}, {
   3.897606797528143*^9, 3.897606798020647*^9}, {3.897660031593266*^9, 
   3.897660031602867*^9}, {3.897660696383986*^9, 3.897660804511832*^9}, {
   3.8976609080281982`*^9, 3.897660955674176*^9}, {3.897661003743726*^9, 
   3.897661025662693*^9}, 3.897661187075543*^9, {3.897661444785392*^9, 
   3.8976616531910353`*^9}, {3.8976617012810907`*^9, 3.897661738643257*^9}, {
   3.897662129198621*^9, 3.897662148044298*^9}, {3.89768840404949*^9, 
   3.897688475537381*^9}, {3.8976889765237503`*^9, 3.8976890186154823`*^9}, {
   3.897689103085577*^9, 3.897689106304206*^9}, {3.897691201486549*^9, 
   3.897691363076695*^9}},
 TextJustification->1.,
 CellLabel->"In[7]:=",ExpressionUUID->"cb998c7e-4b86-4b93-9dfd-cd0d53de4612"]
}, Open  ]]
},
WindowSize->{1440., 782.25},
WindowMargins->{{3.3301325139235587`, Automatic}, {Automatic, 0}},
Magnification:>1.2 Inherited,
FrontEndVersion->"13.2 for Linux x86 (64-bit) (January 31, 2023)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"5ed20a59-29a1-4cda-ba98-39fce292b1a1"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 1076, 27, 144, "Subtitle",ExpressionUUID->"b0255901-d493-4cff-84f7-c351a606fc1a"],
Cell[1659, 51, 386, 8, 45, "Text",ExpressionUUID->"a9e538f1-f95d-45af-9975-e1a03160a1e5"],
Cell[2048, 61, 3175, 92, 124, "Text",ExpressionUUID->"4742f0dd-3fe5-4ecb-8b9a-20d8521eceb0"],
Cell[5226, 155, 1381, 30, 136, "Text",ExpressionUUID->"f9b8c0fe-e360-49c2-8840-dbcd62f0fb3e"],
Cell[6610, 187, 37949, 832, 2563, "Input",ExpressionUUID->"cb998c7e-4b86-4b93-9dfd-cd0d53de4612"]
}, Open  ]]
}
]
*)

